@@ -12,13 +12,13 @@
 // release build
 #undef NDEBUG
 #include <cassert>
-#define NDEBUG
 #else
 // debug build
 #include <cassert>
 #endif
 
 #include <iostream>
+#include <sstream>
 #include <chrono>
 
 namespace orcus { namespace test {
@@ -49,8 +49,18 @@ public:
 void verify_content(
     const char* filename, size_t line_no, std::string_view expected, const std::string& actual);
 
+template<typename EnumT>
+bool verify_stream_value(EnumT v, std::string_view expected)
+{
+    std::ostringstream os;
+    os << v;
+    return os.str() == expected;
+}
+
 }} // namespace orcus::test
 
+#define ORCUS_TEST_FUNC_SCOPE orcus::test::stack_printer __sp__(__func__)
+
 #endif
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
