@@ -25,25 +25,27 @@ using namespace orcus::spreadsheet::mock;
 class mock_sheet_properties : public import_sheet_properties
 {
 public:
-    virtual void set_column_width(col_t col, double size, length_unit_t unit)
+    virtual void set_column_width(col_t col, col_t col_span, double size, length_unit_t unit)
     {
         assert(col == 2);
+        assert(col_span == 1);
         assert(size == 37.3);
         assert(unit == length_unit_t::point);
     }
 
-    virtual void set_column_hidden(col_t, bool)
+    virtual void set_column_hidden(col_t, col_t, bool)
     {
     }
 
-    virtual void set_row_height(row_t row, double size, length_unit_t unit)
+    virtual void set_row_height(row_t row, row_t row_span, double size, length_unit_t unit)
     {
         assert(row == 4);
+        assert(row_span == 1);
         assert(size == 7.3);
         assert(unit == length_unit_t::point);
     }
 
-    virtual void set_row_hidden(row_t, bool)
+    virtual void set_row_hidden(row_t, row_t, bool)
     {
     }
 };
@@ -70,10 +72,11 @@ private:
 class mock_factory : public import_factory
 {
 public:
-    virtual iface::import_sheet* append_sheet(sheet_t, std::string_view) override
+    virtual iface::import_sheet* get_sheet(std::string_view) override
     {
         return &m_mock_sheet;
     }
+
 private:
     mock_sheet m_mock_sheet;
 };
@@ -83,21 +86,22 @@ void test_column_width()
     mock_factory factory;
     session_context cxt;
 
-    orcus::gnumeric_sheet_context context(cxt, orcus::gnumeric_tokens, &factory, 0);
+    orcus::gnumeric_sheet_context context(cxt, orcus::gnumeric_tokens, &factory);
+    context.reset(0);
     orcus::xmlns_id_t ns = NS_gnumeric_gnm;
     orcus::xml_token_t parent = XML_Sheet;
-    orcus::xml_attrs_t parent_attr;
+    orcus::xml_token_attrs_t parent_attr;
     context.start_element(ns, parent, parent_attr);
     {
         orcus::xml_token_t elem = XML_Name;
-        orcus::xml_attrs_t attrs;
+        orcus::xml_token_attrs_t attrs;
         context.start_element(ns, elem, attrs);
         context.characters("test", false);
         context.end_element(ns, elem);
     }
     {
         orcus::xml_token_t elem = XML_ColInfo;
-        orcus::xml_attrs_t attrs;
+        orcus::xml_token_attrs_t attrs;
         attrs.push_back(xml_token_attr_t(ns, XML_No, "2", false));
         attrs.push_back(xml_token_attr_t(ns, XML_Unit, "37.3", false));
         attrs.push_back(xml_token_attr_t(ns, XML_Unit, "37.3", false));
