@@ -22,7 +22,7 @@ int main(int argc, char** argv) try
     spreadsheet::import_factory fact(doc);
     orcus_gnumeric app(&fact);
 
-    if (parse_import_filter_args(argc, argv, fact, app, doc))
+    if (!parse_import_filter_args(argc, argv, fact, app, doc))
         return EXIT_FAILURE;
 
     return EXIT_SUCCESS;
