@@ -13,7 +13,6 @@
 #include "orcus/stream.hpp"
 #include "orcus/xml_namespace.hpp"
 #include "orcus/dom_tree.hpp"
-#include "orcus/global.hpp"
 
 #include <iostream>
 #include <fstream>
@@ -23,26 +22,17 @@
 
 #include <mdds/sorted_string_map.hpp>
 #include <boost/program_options.hpp>
-#include <boost/filesystem.hpp>
 
-using namespace std;
+#include "filesystem_env.hpp"
+
 using namespace orcus;
 namespace po = boost::program_options;
-namespace fs = boost::filesystem;
 
 namespace orcus { namespace detail {
 
-cmd_params::cmd_params() {}
-
-cmd_params::cmd_params(cmd_params&& other) :
-    config(std::move(other.config)),
-    os(std::move(other.os)),
-    mode(other.mode),
-    map_file(std::move(other.map_file))
-{
-}
-
-cmd_params::~cmd_params() {}
+cmd_params::cmd_params() = default;
+cmd_params::cmd_params(cmd_params&& other) = default;
+cmd_params::~cmd_params() = default;
 
 }}
 
@@ -50,20 +40,22 @@ namespace {
 
 namespace mode {
 
-typedef mdds::sorted_string_map<detail::mode_t> map_type;
+using map_type = mdds::sorted_string_map<detail::mode_t>;
 
 // Keys must be sorted.
-const std::vector<map_type::entry> entries =
+constexpr map_type::entry_type entries[] =
 {
-    { ORCUS_ASCII("convert"),   detail::mode_t::convert   },
-    { ORCUS_ASCII("map"),       detail::mode_t::map       },
-    { ORCUS_ASCII("map-gen"),   detail::mode_t::map_gen   },
-    { ORCUS_ASCII("structure"), detail::mode_t::structure },
+    { "convert",   detail::mode_t::convert   },
+    { "lint",      detail::mode_t::lint      },
+    { "map",       detail::mode_t::map       },
+    { "map-gen",   detail::mode_t::map_gen   },
+    { "structure", detail::mode_t::structure },
+    { "subtree",   detail::mode_t::subtree   },
 };
 
 const map_type& get()
 {
-    static map_type mt(entries.data(), entries.size(), detail::mode_t::unknown);
+    static map_type mt(entries, std::size(entries), detail::mode_t::unknown);
     return mt;
 }
 
@@ -85,29 +77,39 @@ const char* help_json_output_format =
 "  * no output (none)";
 
 const char* help_json_map =
-"Path to a map file.  This parameter is only used for map mode, and it is "
-"required for map mode."
+"Path to a map file.  This parameter is only used in map mode, and it is "
+"required in that mode."
+;
+
+const char* help_indent =
+"Number of whitespace characters to use for one indent level.  This is applicable "
+"when the command generates output in JSON format."
+;
+
+const char* help_json_path =
+"JSONPath expression specifying the root of a subtree to extract.  It is only used "
+"in subtree mode."
 ;
 
 const char* err_no_input_file = "No input file.";
 
 void print_json_usage(std::ostream& os, const po::options_description& desc)
 {
-    os << "Usage: orcus-json [options] FILE" << endl << endl;
-    os << help_program << endl << endl << desc;
+    os << "Usage: orcus-json [options] FILE\n\n";
+    os << help_program << "\n\n" << desc;
 }
 
 std::string build_mode_help_text()
 {
     std::ostringstream os;
     os << "Mode of operation. Select one of the following options: ";
-    auto it = mode::entries.cbegin(), ite = mode::entries.cend();
+    auto it = mode::entries, ite = mode::entries + std::size(mode::entries);
     --ite;
 
     for (; it != ite; ++it)
-        os << std::string(it->key, it->keylen) << ", ";
+        os << it->key << ", ";
 
-    os << "or " << std::string(it->key, it->keylen) << ".";
+    os << "or " << it->key << ".";
     return os.str();
 }
 
@@ -117,30 +119,50 @@ std::string build_mode_help_text()
 void parse_args_for_convert(
     detail::cmd_params& params, const po::options_description& desc, const po::variables_map& vm)
 {
+    if (vm.count("indent"))
+        params.indent = vm["indent"].as<std::size_t>();
+
     if (vm.count("resolve-refs"))
         params.config->resolve_references = true;
 
     if (vm.count("output-format"))
     {
-        std::string s = vm["output-format"].as<string>();
-        params.config->output_format = to_dump_format_enum(s);
+        std::string s = vm["output-format"].as<std::string>();
+        params.output_format = to_dump_format_enum(s);
 
-        if (params.config->output_format == dump_format_t::unknown)
+        if (params.output_format == dump_format_t::unknown)
         {
-            cerr << "Unknown output format type '" << s << "'." << endl;
+            std::cerr << "Unknown output format type '" << s << "'." << std::endl;
             params.config.reset();
             return;
         }
     }
     else
     {
-        cerr << "Output format is not specified." << endl;
-        print_json_usage(cerr, desc);
+        std::cerr << "Output format is not specified." << std::endl;
+        print_json_usage(std::cerr, desc);
         params.config.reset();
         return;
     }
 }
 
+void parse_args_for_lint(
+    detail::cmd_params& params, const po::options_description& /*desc*/, const po::variables_map& vm)
+{
+    if (vm.count("indent"))
+        params.indent = vm["indent"].as<std::size_t>();
+}
+
+void parse_args_for_subtree(
+    detail::cmd_params& params, const po::options_description& /*desc*/, const po::variables_map& vm)
+{
+    if (vm.count("indent"))
+        params.indent = vm["indent"].as<std::size_t>();
+
+    if (vm.count("path"))
+        params.json_path = vm["path"].as<std::string>();
+}
+
 /**
  * Reset params.config in case of failure.
  */
@@ -152,7 +174,7 @@ void parse_args_for_map(
         fs::path map_path = vm["map"].as<std::string>();
         if (!fs::is_regular_file(map_path))
         {
-            cerr << map_path.string() << " is not a valid file." << endl;
+            std::cerr << map_path.string() << " is not a valid file." << std::endl;
             params.config.reset();
             return;
         }
@@ -180,14 +202,16 @@ detail::cmd_params parse_json_args(int argc, char** argv)
         ("help,h", "Print this help.")
         ("mode", po::value<std::string>(), build_mode_help_text().data())
         ("resolve-refs", "Resolve JSON references to external files.")
-        ("output,o", po::value<string>(), help_json_output)
-        ("output-format,f", po::value<string>(), help_json_output_format)
-        ("map,m", po::value<string>(), help_json_map)
+        ("output,o", po::value<std::string>(), help_json_output)
+        ("output-format,f", po::value<std::string>(), help_json_output_format)
+        ("map,m", po::value<std::string>(), help_json_map)
+        ("indent,i", po::value<std::size_t>(), help_indent)
+        ("path,p", po::value<std::string>(), help_json_path)
     ;
 
     po::options_description hidden("Hidden options");
     hidden.add_options()
-        ("input", po::value<string>(), "input file");
+        ("input", po::value<std::string>(), "input file");
 
     po::options_description cmd_opt;
     cmd_opt.add(desc).add(hidden);
@@ -202,27 +226,27 @@ detail::cmd_params parse_json_args(int argc, char** argv)
             po::command_line_parser(argc, argv).options(cmd_opt).positional(po_desc).run(), vm);
         po::notify(vm);
     }
-    catch (const exception& e)
+    catch (const std::exception& e)
     {
         // Unknown options.
-        cerr << e.what() << endl;
-        print_json_usage(cerr, desc);
+        std::cerr << e.what() << std::endl;
+        print_json_usage(std::cerr, desc);
         return params;
     }
 
     if (vm.count("help"))
     {
-        print_json_usage(cout, desc);
+        print_json_usage(std::cout, desc);
         return params;
     }
 
     if (vm.count("mode"))
     {
         std::string s = vm["mode"].as<std::string>();
-        params.mode = mode::get().find(s.data(), s.size());
+        params.mode = mode::get().find(s);
         if (params.mode == detail::mode_t::unknown)
         {
-            cerr << "Unknown mode string '" << s << "'." << endl;
+            std::cerr << "Unknown mode string '" << s << "'." << std::endl;
             return params;
         }
     }
@@ -230,26 +254,26 @@ detail::cmd_params parse_json_args(int argc, char** argv)
     params.config = std::make_unique<json_config>();
 
     if (vm.count("input"))
-        params.config->input_path = vm["input"].as<string>();
+        params.config->input_path = vm["input"].as<std::string>();
 
     if (params.config->input_path.empty())
     {
         // No input file is given.
-        cerr << err_no_input_file << endl;
-        print_json_usage(cerr, desc);
+        std::cerr << err_no_input_file << std::endl;
+        print_json_usage(std::cerr, desc);
         params.config.reset();
         return params;
     }
 
     if (!fs::exists(params.config->input_path))
     {
-        cerr << "Input file does not exist: " << params.config->input_path << endl;
+        std::cerr << "Input file does not exist: " << params.config->input_path << std::endl;
         params.config.reset();
         return params;
     }
 
     if (vm.count("output"))
-        params.config->output_path = vm["output"].as<string>();
+        params.output_path = vm["output"].as<std::string>();
 
     switch (params.mode)
     {
@@ -265,6 +289,14 @@ detail::cmd_params parse_json_args(int argc, char** argv)
         case detail::mode_t::map:
             parse_args_for_map(params, desc, vm);
             break;
+        case detail::mode_t::lint:
+            params.os = std::make_unique<output_stream>(vm);
+            parse_args_for_lint(params, desc, vm);
+            break;
+        case detail::mode_t::subtree:
+            params.os = std::make_unique<output_stream>(vm);
+            parse_args_for_subtree(params, desc, vm);
+            break;
         default:
             assert(!"This should not happen since the mode check is done way earlier.");
     }
@@ -284,7 +316,7 @@ void build_doc_and_dump(const orcus::file_content& content, detail::cmd_params&
     std::unique_ptr<json::document_tree> doc = load_doc(content, *params.config);
     std::ostream& os = params.os->get();
 
-    switch (params.config->output_format)
+    switch (params.output_format)
     {
         case dump_format_t::xml:
         {
@@ -293,7 +325,7 @@ void build_doc_and_dump(const orcus::file_content& content, detail::cmd_params&
         }
         case dump_format_t::json:
         {
-            os << doc->dump();
+            os << doc->dump(params.indent);
             break;
         }
         case dump_format_t::yaml:
@@ -303,7 +335,7 @@ void build_doc_and_dump(const orcus::file_content& content, detail::cmd_params&
         }
         case dump_format_t::check:
         {
-            string xml_strm = doc->dump_xml();
+            std::string xml_strm = doc->dump_xml();
             xmlns_repository repo;
             xmlns_context ns_cxt = repo.create_context();
             dom::document_tree dom(ns_cxt);
@@ -377,7 +409,7 @@ void parse_and_write_map_file(const orcus::file_content& content, detail::cmd_pa
     }
 
     std::ostream& os = params.os->get();
-    os << map_doc.dump();
+    os << map_doc.dump(4);
 }
 
 } // anonymous namespace
@@ -421,20 +453,35 @@ int main(int argc, char** argv)
                 build_doc_and_dump(content, params);
                 break;
             }
+            case detail::mode_t::lint:
+            {
+                auto doc = load_doc(content, *params.config);
+                std::ostream& os = params.os->get();
+                os << doc->dump(params.indent);
+                break;
+            }
+            case detail::mode_t::subtree:
+            {
+                auto doc = load_doc(content, *params.config);
+                std::ostream& os = params.os->get();
+                auto sub = json::subtree(*doc, params.json_path);
+                os << sub.dump(params.indent);
+                break;
+            }
             default:
-                cerr << "Unkonwn mode has been given." << endl;
+                std::cerr << "Unkonwn mode has been given." << std::endl;
                 return EXIT_FAILURE;
         }
     }
-    catch (const json::parse_error& e)
+    catch (const parse_error& e)
     {
-        cerr << create_parse_error_output(content.str(), e.offset()) << endl;
-        cerr << e.what() << endl;
+        std::cerr << create_parse_error_output(content.str(), e.offset()) << std::endl;
+        std::cerr << e.what() << std::endl;
         return EXIT_FAILURE;
     }
     catch (const std::exception& e)
     {
-        cerr << e.what() << endl;
+        std::cerr << e.what() << std::endl;
         return EXIT_FAILURE;
     }
 
